@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,43 +25,43 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Adm.php,v 1.1 2008/12/01 17:45:53 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Adm.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * DB饹
+ * DBクラス
  */
 SyL_Loader::lib('DB');
 /**
- * ե饹
+ * ファイル処理クラス
  */
 SyL_Loader::lib('File');
 
 /**
- * ADMѥեDAOѥơ֥륯饹륯饹
+ * ADM用アクションフォームとDAO用テーブルクラスを作成するクラス
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Adm.php,v 1.1 2008/12/01 17:45:53 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Adm.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class Adm extends AppAction
 {
     /**
-     * ơ֥륪֥Ⱥǥ쥯ȥ
+     * テーブルオブジェクト作成ディレクトリ
      *
      * @access private
      * @var string
      */
     var $table_dir = 'Adm.Tables.';
     /**
-     * ե४֥Ⱥǥ쥯ȥ
+     * フォームオブジェクト作成ディレクトリ
      *
      * @access private
      * @var string
@@ -69,11 +69,11 @@ class Adm extends AppAction
     var $form_dir = 'Adm.Forms.';
 
     /**
-     * ᥤ
+     * メイン処理
      *
      * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
+     * @param object データオブジェクト
+     * @param object コンテキストオブジェクト
      */
     function execute(&$data, &$context)
     {
@@ -89,7 +89,7 @@ class Adm extends AppAction
         $cmd->stdout("  parameters checking...");
 
         // -------------------------------------------------
-        // ץȥǥ쥯ȥå
+        // プロジェクトディレクトリチェック
         // -------------------------------------------------
         if (!is_dir($project_dir)) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
@@ -97,7 +97,7 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ץꥱ̾å
+        // アプリケーション名チェック
         // -------------------------------------------------
         $app_dir = '';
         if (!$app_name) {
@@ -111,7 +111,7 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ơ֥̾å
+        // テーブル名チェック
         // -------------------------------------------------
         if (!$table_name) {
             trigger_error("[SyL error] Table name (-t) not found", E_USER_ERROR);
@@ -121,7 +121,7 @@ class Adm extends AppAction
         $mkdirs = array();
 
         // -------------------------------------------------
-        // ץȥǥ쥯ȥå
+        // プロジェクトディレクトリチェック
         // -------------------------------------------------
         $cmd->stdout("  project application directory checking...");
 
@@ -170,7 +170,7 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ơ֥ǥ쥯ȥå
+        // テーブルディレクトリチェック
         // -------------------------------------------------
         $cmd->stdout("  project lib table directory checking...");
 
@@ -206,7 +206,7 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // եǥ쥯ȥå
+        // フォームディレクトリチェック
         // -------------------------------------------------
         $cmd->stdout("  project lib form directory checking...");
 
@@ -242,10 +242,11 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ƥġʥȥ˥ǥ쥯ȥå
+        // コンテンツ（コントローラ）ディレクトリチェック
         // -------------------------------------------------
         $image_dir = '';
         $css_dir   = '';
+        $js_dir    = '';
         if ($controller_dir) {
             $cmd->stdout("  images or css directory checking...");
 
@@ -267,7 +268,7 @@ class Adm extends AppAction
                 $mkdirs[] = $image_dir;
             }
 
-            $css_dir   = "{$controller_dir}/css";
+            $css_dir = "{$controller_dir}/css";
             if (file_exists($css_dir)) {
                 if (!is_dir($css_dir)) {
                     trigger_error("[SyL error] Unable create `css' directory. Already file exist ({$css_dir})", E_USER_ERROR);
@@ -284,10 +285,29 @@ class Adm extends AppAction
                 }
                 $mkdirs[] = $css_dir;
             }
+
+            $js_dir = "{$controller_dir}/js";
+            if (file_exists($js_dir)) {
+                if (!is_dir($js_dir)) {
+                    trigger_error("[SyL error] Unable create `js' directory. Already file exist ({$js_dir})", E_USER_ERROR);
+                }
+                if ($cmd->getInput('', "Already `js' directory exist. overwrite directory ? ({$js_dir}) [Y/n]:") != 'Y') {
+                    return;
+                }
+                if (!is_writable($js_dir)) {
+                    trigger_error("[SyL error] Invalid `js' directory check. create permission denied ? ({$js_dir})", E_USER_ERROR);
+                }
+            } else {
+                if (!is_writable(dirname($js_dir))) {
+                    trigger_error("[SyL error] Invalid `js' directory check. create permission denied ? ({$js_dir})", E_USER_ERROR);
+                }
+                $mkdirs[] = $js_dir;
+            }
+
         }
 
         // -------------------------------------------------
-        // եå
+        // 設定ファイルチェック
         // -------------------------------------------------
         $cmd->stdout("  project or application config checking...");
 
@@ -299,13 +319,13 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // DB³ʸμ
+        // DB接続文字列の取得
         // -------------------------------------------------
         $cmd->stdout("  project or application config `SYL_DB_DSN' getting...");
         $connection_string = $this->getConnectionString($project_config_file, $app_config_file);
 
         // -------------------------------------------------
-        // ơ֥륹޾μ
+        // テーブルスキーマ情報の取得
         // -------------------------------------------------
         $cmd->stdout("  table schema scaning...");
         list($table_columns, $table_primary, $table_uniques, $table_foreigns) = $this->getTableSchema($connection_string, $table_name);
@@ -314,7 +334,7 @@ class Adm extends AppAction
             trigger_error("[SyL error] Table schema not found ({$table_name})", E_USER_ERROR);
         }
 
-        // ʸ
+        // 大文字統一
         $table_primary = array_map('strtoupper', $table_primary);
         for ($i=0; $i<count($table_uniques); $i++) {
             $table_uniques[$i] = array_map('strtoupper', $table_uniques[$i]);
@@ -325,7 +345,7 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ǥ쥯ȥ
+        // ディレクトリ作成
         // -------------------------------------------------
         $cmd->stdout("  create directories...");
 
@@ -337,15 +357,15 @@ class Adm extends AppAction
         }
 
         // -------------------------------------------------
-        // ե
+        // ファイル作成
         // -------------------------------------------------
         $cmd->stdout("  create files...");
 
-        // ƥץ졼ȥե
+        // テンプレートファイル
         $template_table_file = SYL_PROJECT_DIR . '/var/templates/Table.php';
         $template_form_file  = SYL_PROJECT_DIR . '/var/templates/Form.php';
 
-        // ơ֥ե
+        // テーブルファイル作成
         $cmd->stdout("  table template file: {$template_table_file}");
 
         $cmd->stdout("    -> creating table class...");
@@ -354,7 +374,7 @@ class Adm extends AppAction
         $cmd->stdout("    -> generating table class file... {$table_file}");
         SyL_File::writeContents($table_file, $table_class_source);
 
-        // եե
+        // フォームファイル作成
         $cmd->stdout("  form template file: {$template_form_file}");
 
         $cmd->stdout("    -> creating form class...");
@@ -364,28 +384,28 @@ class Adm extends AppAction
         SyL_File::writeContents($form_file, $form_class_source);
 
         if ($action_name) {
-            // ե饹Ѵ
+            // フォーム操作クラス用変換配列初期化
             $form_opp_search  = array();
             $form_opp_replace = array();
             if ($action_name) {
-                // ץ̾
+                // プロジェクト名
                 $form_opp_search[]  = '{PROJECT_NAME}';
                 $form_opp_replace[] = basename($project_dir);
-                // ǥ쥯ȥ
+                // アクションディレクトリ
                 $form_opp_search[]  = '{ACTION_DIR}';
                 $form_opp_replace[] = (count($action_names) > 0) ? implode('_', $action_names) . '_' : '';
-                // ƥץ졼ȥǥ쥯ȥ
+                // テンプレートディレクトリ
                 $form_opp_search[]  = '{TEMPLATE_DIR}';
                 $form_opp_replace[] = (count($action_names) > 0) ? implode('/', $action_names) . '/' : '';
-                // ե९饹̾
+                // フォームクラス名
                 $form_opp_search[]  = '{FORM_CLASS_NAME}';
                 $form_opp_replace[] = SyL_Loader::convertClass($form_class);
-                // ե९饹ѥ
+                // フォームクラスパス
                 $form_opp_search[]  = '{FORM_CLASS_PATH}';
                 $form_opp_replace[] = $form_class;
             }
 
-            // ե
+            // アクションファイル作成
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Index.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
@@ -435,7 +455,7 @@ class Adm extends AppAction
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
-            // ƥץ졼ȥե
+            // テンプレートファイル作成
             $dir = ($smarty_flag) ? 'smarty' : 'default';
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Lst.html";
@@ -474,7 +494,7 @@ class Adm extends AppAction
             SyL_File::writeContents($create_file, file_get_contents($template_file));
         }
 
-        // ե륳ԡ
+        // 画像ファイルコピー
         if ($image_dir) {
             $dir = SYL_PROJECT_DIR . '/var/templates/images';
             if ($dh = opendir($dir)) {
@@ -489,7 +509,7 @@ class Adm extends AppAction
             }
         }
 
-        // CSSե륳ԡ
+        // CSSファイルコピー
         if ($css_dir) {
             $dir = SYL_PROJECT_DIR . '/var/templates/css';
             if ($dh = opendir($dir)) {
@@ -504,8 +524,24 @@ class Adm extends AppAction
             }
         }
 
+        // JSファイルコピー
+        if ($js_dir) {
+            $dir = SYL_PROJECT_DIR . '/var/templates/js';
+            if ($dh = opendir($dir)) {
+                while (($file = readdir($dh)) !== false) {
+                    if (($file != '.') && ($file != '..')) {
+                        $cmd->stdout("  copying file {$dir}/{$file}");
+                        $cmd->stdout("    -> {$js_dir}/{$file}");
+                        copy("{$dir}/{$file}", "{$js_dir}/{$file}");
+                    }
+                }
+                closedir($dh);
+            }
+        }
+
+
         // -------------------------------------------------
-        // ɽ
+        // 結果表示
         // -------------------------------------------------
 
         $cmd->stdout("");
@@ -532,5 +568,3 @@ class Adm extends AppAction
         }
     }
 }
-
-?>
