@@ -1,44 +1,44 @@
 <?php
 /**
- * {FORM_CLASS_NAME}ե९饹
+ * {FORM_CLASS_NAME}フォームクラス
  *
  * @access    public
  * @package   {PROJECT_NAME}
  * @author    {author}
- * @version   $Id: Form.php,v 1.1 2008/12/01 17:45:52 seasonstream Exp $
+ * @version   $Id: Form.php,v 1.2 2009/01/11 05:34:33 seasonstream Exp $
  */
 class {FORM_CLASS_NAME} extends SyL_AdmActionForm
 {
 /**
- * ơ֥륯饹
+ * テーブルクラスの配列
  * 
  * @access protected
  * @var array
  */
 var $table_classes = {FORM_TABLES};
 /**
- * ơ֥륯饹δϢ
+ * テーブルクラスの関連配列
  * 
  * @access protected
  * @var array
  */
 var $table_relations = array();
 /**
- * ᥤƥʥ󥹥ơ֥̾
+ * メインメンテナンステーブル名
  * 
  * @access protected
  * @var string
  */
 var $maintenance_table = '{FORM_MAINTENANCE_TABLE}';
 /**
- * ϢURL
+ * 関連リンクURL
  * 
  * @access protected
  * @var array
  */
 var $related_links = array();
 /**
- * 
+ * 構成定義設定配列
  * 
  * @access protected
  * @var array
@@ -49,7 +49,7 @@ var $structs_config = array(
   'default_search_view' => false,
   'page_records'        => 20,
   'link_range'          => 9,
-  'key_name'            => 'key',
+  'key_name'            => 'id',
   'view_confirm'        => true,
   'view_fin'            => true,
   'view_alert'          => false,
@@ -61,7 +61,7 @@ var $structs_config = array(
   'enable_sch'          => true
 );
 /**
- * ե
+ * フォーム定義要素配列
  * 
  * @access protected
  * @var array
@@ -69,5 +69,3 @@ var $structs_config = array(
 var $elements_config = {FORM_ELEMENTS};
 
 }
-
-?>
