@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,33 +25,33 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Controller.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Controller.php,v 1.5 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ȥե饹
+ * コントローラファイル作成クラス
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Controller.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Controller.php,v 1.5 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class Controller extends AppAction
 {
-    var $c_controller; // 󥸥
+    var $c_controller; // インジェクション
 
     /**
-     * ȥ
+     * コントローラ作成処理
      *
      * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
+     * @param object データオブジェクト
+     * @param object コンテキストオブジェクト
      */
     function execute(&$data, &$context)
     {
@@ -63,7 +63,7 @@ class Controller extends AppAction
         $cmd =& $context->getConsole();
 
         // -------------------------------------------------
-        // ץȥǥ쥯ȥå
+        // プロジェクトディレクトリチェック
         // -------------------------------------------------
         if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
@@ -78,7 +78,7 @@ class Controller extends AppAction
         }
 
         // -------------------------------------------------
-        // ץꥱ̾å
+        // アプリケーション名チェック
         // -------------------------------------------------
         if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
@@ -95,11 +95,11 @@ class Controller extends AppAction
         }
 
         // -------------------------------------------------
-        // ȥեå
+        // コントローラファイルチェック
         // -------------------------------------------------
         if ($is_controller) {
             if (!$controller_file) {
-                // ǥեȤΥȥե
+                // デフォルトのコントローラファイル
                 $controller_file = "{$project_dir}public/{$app_name}.php";
             }
             if (file_exists($controller_file)) {
@@ -123,11 +123,9 @@ class Controller extends AppAction
         }
 
         // -------------------------------------------------
-        // ȥե
+        // コントローラファイル作成
         // -------------------------------------------------
         $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
     }
 
 }
-
-?>
