@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,37 +25,37 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.6 2008/11/09 10:05:35 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Index.php,v 1.7 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ץȺ饹
+ * プロジェクト作成クラス
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.6 2008/11/09 10:05:35 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Index.php,v 1.7 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class Index extends AppAction
 {
-    var $c_action; // 󥸥
-    var $c_application; // 󥸥
-    var $c_controller; // 󥸥
-    var $c_template; // 󥸥
-    var $c_project; // 󥸥
+    var $c_action; // インジェクション
+    var $c_application; // インジェクション
+    var $c_controller; // インジェクション
+    var $c_template; // インジェクション
+    var $c_project; // インジェクション
 
     /**
-     * ᥤ
+     * メイン処理
      *
      * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
+     * @param object データオブジェクト
+     * @param object コンテキストオブジェクト
      */
     function execute(&$data, &$context)
     {
@@ -105,10 +105,10 @@ class Index extends AppAction
             $obj->execute($data, $context);
             break;
         default:
-            // С󥳥ޥ
+            // バージョンコマンド
             if ($data->is('h') || $data->is('help')) {
                 $this->displayHelp($cmd, $data->get(0));
-            // إץޥ
+            // ヘルプコマンド
             } else if ($data->is('v') || $data->is('version')) {
                 $this->displayVersion($cmd, $data->get(0));
             } else {
@@ -118,11 +118,11 @@ class Index extends AppAction
     }
 
     /**
-     * إפɽ
+     * ヘルプを表示
      *
      * @access private
-     * @param object ޥɥ֥
-     * @param string ¹ԥե̾
+     * @param object コマンドオブジェクト
+     * @param string 実行ファイル名
      */
     function displayHelp(&$cmd, $file)
     {
@@ -149,11 +149,11 @@ EOF;
     }
 
     /**
-     * Сɽ
+     * バージョン情報を表示
      *
      * @access private
-     * @param object ޥɥ֥
-     * @param string ¹ԥե̾
+     * @param object コマンドオブジェクト
+     * @param string 実行ファイル名
      */
     function displayVersion(&$cmd, $file)
     {
@@ -169,11 +169,11 @@ EOF;
     }
 
     /**
-     * ǥեɽ
+     * デフォルト表示
      *
      * @access private
-     * @param object ޥɥ֥
-     * @param string ¹ԥե̾
+     * @param object コマンドオブジェクト
+     * @param string 実行ファイル名
      */
     function displayDefault(&$cmd, $file)
     {
@@ -184,5 +184,3 @@ EOF;
         $cmd->stdout($default);
     }
 }
-
-?>
