@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,32 +25,32 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.10 2008/12/01 17:45:53 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: CreateApplication.php,v 1.11 2009/01/11 05:34:32 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ץꥱǥ쥯ȥݡͥȥ饹
+ * アプリケーションディレクトリ作成コンポーネントクラス
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.10 2008/12/01 17:45:53 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: CreateApplication.php,v 1.11 2009/01/11 05:34:32 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class CreateApplication
 {
     /**
-     * ץꥱǥ쥯ȥ
+     * アプリケーションディレクトリ作成
      *
      * @access public
-     * @param object 󥽡륪֥
-     * @param string ץȥǥ쥯ȥ
-     * @param string ץꥱ̾
+     * @param object コンソールオブジェクト
+     * @param string プロジェクトディレクトリ
+     * @param string アプリケーション名
      */
     function trigger(&$cmd, $project_dir, $app_name)
     {
@@ -84,6 +84,8 @@ class CreateApplication
           'filters.xml'     => 'config/filters.xml',
           'layouts.xml'     => 'config/layouts.xml',
           'routers.xml'     => 'config/routers.xml',
+          'Error404.php'    => 'lib/Error404.php',
+          'Error500.php'    => 'lib/Error500.php',
           'AppAction.php'   => 'lib/App/AppAction.php',
           'AppUser.php'     => 'lib/App/AppUser.php'
         );
@@ -101,10 +103,8 @@ class CreateApplication
             if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
                 copy("{$project_dir}var/skel-templates/{$file_org}", "{$app_dir}{$file_dist}");
             } else {
-                copy(SYL_PROJECT_DIR . '/var/skel-templates/{$file_org}', "{$app_dir}{$file_dist}");
+                copy(SYL_PROJECT_DIR . "/var/skel-templates/{$file_org}", "{$app_dir}{$file_dist}");
             }
         }
     }
 }
-
-?>
