@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,32 +25,32 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.7 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: CreateProject.php,v 1.8 2009/01/11 05:34:32 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ץȥǥ쥯ȥݡͥȥ饹
+ * プロジェクトディレクトリ作成コンポーネントクラス
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.7 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: CreateProject.php,v 1.8 2009/01/11 05:34:32 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class CreateProject
 {
     /**
-     * ץȥǥ쥯ȥ
+     * プロジェクトディレクトリ作成
      *
      * @access public
-     * @param object 󥽡륪֥
-     * @param string ץȥǥ쥯ȥ
-     * @param string Smartyǥ쥯ȥ
+     * @param object コンソールオブジェクト
+     * @param string プロジェクトディレクトリ
+     * @param string Smartyディレクトリ
      */
     function trigger(&$cmd, $project_dir, $smarty_dir)
     {
@@ -65,7 +65,6 @@ class CreateProject
           'apps'        => 0755,
           'config'      => 0755,
           'lib'         => 0755,
-          'lib/Common'  => 0755,
           'public'      => 0755,
           'var'         => 0755,
           'var/cache'   => 0777,
@@ -81,8 +80,6 @@ class CreateProject
           'defines.xml'    => 'config/defines.xml',
           'filters.xml'    => 'config/filters.xml',
           'components.xml' => 'config/components.xml',
-          'DefaultErrorWeb.php' => 'lib/Common/DefaultErrorWeb.php',
-          'Error404.php'  => 'lib/Common/Error404.php',
         );
 
         foreach ($dirs as $dir => $mode) {
@@ -128,5 +125,3 @@ class CreateProject
         closedir($dh);
     }
 }
-
-?>
